summaryrefslogtreecommitdiff
path: root/src/dispextern.h
diff options
context:
space:
mode:
authorRichard M. Stallman <rms@gnu.org>1993-03-28 05:23:45 +0000
committerRichard M. Stallman <rms@gnu.org>1993-03-28 05:23:45 +0000
commit590370729efbad185a79d61415a1686e15e6589c (patch)
tree79db0125f1b32ac59dee6ecd556c0e988ecc0e0b /src/dispextern.h
parent9510257029d485fa8a61bf1b815a2f0b14441c09 (diff)
downloademacs-590370729efbad185a79d61415a1686e15e6589c.tar.gz
(struct face): New fields pixmap_h, pixmap_w.
Field `font' is now a pointer.
Diffstat (limited to 'src/dispextern.h')
-rw-r--r--src/dispextern.h34
1 files changed, 19 insertions, 15 deletions
diff --git a/src/dispextern.h b/src/dispextern.h
index 38e988cb6da..a89e73120c9 100644
--- a/src/dispextern.h
+++ b/src/dispextern.h
@@ -27,28 +27,32 @@ extern int display_completed;
struct face
{
/* If this is non-zero, it is a GC we can use without modification
- to represent this face. */
+ to represent this face. */
GC gc;
- /* Pixel value for foreground color. */
+ /* Pixel value for foreground color. */
int foreground;
- /* Pixel value for background color. */
+ /* Pixel value for background color. */
int background;
- /* Font used for this face */
- XFontStruct font;
+ /* Font used for this face. */
+ XFontStruct *font;
- /* Background stipple or bitmap used for this face. */
+ /* Background stipple or bitmap used for this face. */
Pixmap stipple;
+
+ /* Pixmap_depth. */
+ unsigned int pixmap_w, pixmap_h;
- /* Whether or not to underline text in this face. */
+ /* Whether or not to underline text in this face. */
char underline;
};
+/* Let's stop using this and get rid of it. */
typedef struct face *FACE;
-#define NORMAL_FACE ((FACE *) 0)
+#define NORMAL_FACE ((struct face *) 0)
#define FACE_HAS_GC(f) ((f)->gc)
#define FACE_GC(f) ((f)->gc)
@@ -76,12 +80,12 @@ typedef int FACE;
There are two instantiations of it: the glyphs currently displayed,
and the glyphs we desire to display. The latter object is generated
- from buffers being displayed. */
+ from buffers being displayed. */
struct frame_glyphs
{
#ifdef MULTI_FRAME
- struct frame *frame; /* Frame these glyphs belong to. */
+ struct frame *frame; /* Frame these glyphs belong to. */
#endif /* MULTI_FRAME */
int height;
int width;
@@ -108,21 +112,21 @@ struct frame_glyphs
/* highlight[n] != 0 iff line n is highlighted. */
char *highlight;
- /* Buffer offset of this line's first char. */
+ /* Buffer offset of this line's first char. */
int *bufp;
#ifdef HAVE_X_WINDOWS
- /* Pixel position of top left corner of line. */
+ /* Pixel position of top left corner of line. */
short *top_left_x;
short *top_left_y;
- /* Pixel width of line. */
+ /* Pixel width of line. */
short *pix_width;
- /* Pixel height of line. */
+ /* Pixel height of line. */
short *pix_height;
- /* Largest font ascent on this line. */
+ /* Largest font ascent on this line. */
short *max_ascent;
#endif /* HAVE_X_WINDOWS */
};